@@ -16,6 +16,7 @@ module XMonad.Actions.Warp (
                            -- * Usage
                            -- $usage
                            banish,
+                           banishScreen,
                            Corner(..),
                            warpToScreen,
                            warpToWindow
@@ -33,11 +34,11 @@ You can use this module with the following in your @~\/.xmonad\/xmonad.hs@:
 
 then add appropriate keybindings to warp the pointer; for example:
 
-> , ((modMask x,   xK_z     ), warpToWindow (1%2) (1%2)) -- @@ Move pointer to currently focused window
+> , ((modm,   xK_z     ), warpToWindow (1%2) (1%2)) -- @@ Move pointer to currently focused window
 >
 >-- mod-ctrl-{w,e,r} @@ Move mouse pointer to screen 1, 2, or 3
 >
->   [((modMask x .|. controlMask, key), warpToScreen sc (1%2) (1%2))
+>   [((modm .|. controlMask, key), warpToScreen sc (1%2) (1%2))
 >       | (key, sc) <- zip [xK_w, xK_e, xK_r] [0..]]
 
 Note that warping to a particular screen may change the focus.
@@ -49,7 +50,7 @@ Note that warping to a particular screen may change the focus.
 
 data Corner = UpperLeft | UpperRight | LowerLeft | LowerRight
 
-{- | Move the mouse cursor to a corner of the screen. Useful for
+{- | Move the mouse cursor to a corner of the focused window. Useful for
    uncluttering things.
 
    Internally, this uses numerical parameters. We parametrize on the 'Corner'
@@ -64,7 +65,22 @@ banish direction = case direction of
                      LowerRight -> warpToWindow 1 1
                      LowerLeft  -> warpToWindow 0 1
                      UpperLeft  -> warpToWindow 0 0
-                     UpperRight  -> warpToWindow 1 0
+                     UpperRight -> warpToWindow 1 0
+
+{- | Same as 'banish' but moves the mouse to the corner of the
+   currently focused screen -}
+banishScreen :: Corner -> X ()
+banishScreen direction = case direction of
+                           LowerRight -> warpToCurrentScreen 1 1
+                           LowerLeft  -> warpToCurrentScreen 0 1
+                           UpperLeft  -> warpToCurrentScreen 0 0
+                           UpperRight -> warpToCurrentScreen 1 0
+    where
+      warpToCurrentScreen h v =
+          do ws <- gets windowset
+             warpToScreen (W.screen $ current ws) h v
+             windows (const ws)
+
 
 fraction :: (Integral a, Integral b) => Rational -> a -> b
 fraction f x = floor (f * fromIntegral x)
