@@ -10,7 +10,7 @@
 -- Stability   :  unstable
 -- Portability :  unportable
 --
--- Layout modfier suitable for workspace with multi-windowed instant messanger
+-- Layout modfier suitable for workspace with multi-windowed instant messenger
 -- (like Psi or Tkabber).
 --
 -----------------------------------------------------------------------------
@@ -45,8 +45,8 @@ import XMonad.Util.WindowProperties
 -- for managing your chat windows (Grid in this example, another useful choice
 -- to consider is Tabbed layout).
 --
--- > myLayouts = withIM (1%7) (ClassName "Tkabber") Grid ||| Full ||| etc..
--- > main = xmonad defaultConfig { layoutHook = myLayouts }
+-- > myLayout = withIM (1%7) (ClassName "Tkabber") Grid ||| Full ||| etc..
+-- > main = xmonad defaultConfig { layoutHook = myLayout }
 --
 -- Here @1%7@ is the part of the screen which your roster will occupy,
 -- @ClassName \"Tkabber\"@ tells xmonad which window is actually your roster.
@@ -122,6 +122,6 @@ instance LayoutClass IM Window where
         let (masterRect, slaveRect) = splitHorizontallyBy r rect
         master <- findM (hasProperty prop) ws
         let positions = case master of
-                Just w -> (w, masterRect) : arrange slaveRect (filter (w /=) ws)
-                Nothing -> arrange rect ws
+                Just w -> (w, masterRect) : arrange defaultRatio slaveRect (filter (w /=) ws)
+                Nothing -> arrange defaultRatio rect ws
         return (positions, Nothing)
