@@ -24,7 +24,7 @@ module XMonad.Util.XSelection (  -- * Usage
                                  putSelection) where
 
 import Control.Concurrent (forkIO)
-import Control.Exception as E (catch)
+import Control.Exception.Extensible as E (catch,SomeException(..))
 import Control.Monad(Monad (return, (>>)), Functor(..), liftM, join)
 import Data.Char (ord)
 import Data.Maybe (fromMaybe)
@@ -69,8 +69,8 @@ getSelection = io $ do
   ty <- E.catch
                (E.catch
                      (internAtom dpy "UTF8_STRING" False)
-                     (\_ -> internAtom dpy "COMPOUND_TEXT" False))
-             (\_ -> internAtom dpy "sTring" False)
+                     (\(E.SomeException _) -> internAtom dpy "COMPOUND_TEXT" False))
+             (\(E.SomeException _) -> internAtom dpy "sTring" False)
   clp <- internAtom dpy "BLITZ_SEL_STRING" False
   xConvertSelection dpy p ty clp win currentTime
   allocaXEvent $ \e -> do
